@@ -1,3 +1,5 @@
+#![allow(clippy::fn_address_comparisons)]
+
 //! # MultiSQL
 //!
 //! `multisql` is a highly modular SQL database engine library written in Rust.
@@ -6,20 +8,18 @@
 //! ## Examples
 //!
 //! ```
-//! use gluesql::{SledStorage, Storage, Glue};
-//! fn main() {
-//! 	let storage = SledStorage::new(&path)
-//! 		.map(Storage::new_sled)
-//! 		.expect("Create Storage");
-//! 	let mut glue = Glue::new(String::from("main"), storage)
-//!     
-//! 	glue.execute_many("
-//! 		DROP TABLE IF EXISTS test;
-//! 		CREATE TABLE test (id INTEGER);
-//! 		INSERT INTO test VALUES (1),(2);
-//! 		SELECT * FROM test WHERE id > 1;
-//! 	");
-//! }
+//! use multisql::{SledStorage, Storage, Glue};
+//! let storage = SledStorage::new("data/example_location/lib_example")
+//!   .map(Storage::new_sled)
+//!   .expect("Storage Creation Failed");
+//! let mut glue = Glue::new(String::from("main"), storage);
+//!
+//! glue.execute_many("
+//!   DROP TABLE IF EXISTS test;
+//!   CREATE TABLE test (id INTEGER);
+//!   INSERT INTO test VALUES (1),(2);
+//!   SELECT * FROM test WHERE id > 1;
+//! ");
 //! ```
 //!
 //! ## See also
