@@ -1,8 +1,6 @@
 use crate::StorageError;
 use {
-	crate::{
-		Cast, Column, Result, Row, RowIter, Schema, SheetStorage, Store, Value,
-	},
+	crate::{Cast, Column, Result, Row, RowIter, Schema, SheetStorage, Store, Value},
 	async_trait::async_trait,
 	std::convert::TryFrom,
 	umya_spreadsheet::{Cell, Worksheet},
